@@ -67,23 +67,20 @@ Mojo::IOLoop::Delay - Promises/A+ and flow-control helpers
   Mojo::IOLoop::Delay->new->steps(
 
     # First step (simple timer)
-    sub {
-      my $delay = shift;
+    sub ($delay) {
       Mojo::IOLoop->timer(2 => $delay->begin);
       say 'Second step in 2 seconds.';
     },
 
     # Second step (concurrent timers)
-    sub {
-      my ($delay, @args) = @_;
+    sub ($delay, @args) {
       Mojo::IOLoop->timer(1 => $delay->begin);
       Mojo::IOLoop->timer(3 => $delay->begin);
       say 'Third step in 3 seconds.';
     },
 
     # Third step (the end)
-    sub {
-      my ($delay, @args) = @_;
+    sub ($delay, @args) {
       say 'And done after 5 seconds total.';
     }
   )->wait;
@@ -96,16 +93,13 @@ that often result from continuation-passing style.
   use Mojo::IOLoop;
 
   # These deep nested closures are often referred to as "Callback Hell"
-  Mojo::IOLoop->timer(3 => sub {
-    my $loop = shift;
+  Mojo::IOLoop->timer(3 => sub ($loop) {
 
     say '3 seconds';
-    Mojo::IOLoop->timer(3 => sub {
-      my $loop = shift;
+    Mojo::IOLoop->timer(3 => sub ($loop) {
 
       say '6 seconds';
-      Mojo::IOLoop->timer(3 => sub {
-        my $loop = shift;
+      Mojo::IOLoop->timer(3 => sub ($loop) {
 
         say '9 seconds';
         Mojo::IOLoop->stop;
@@ -123,24 +117,16 @@ callback, and that leads to the next closure in the series when executed.
 
   # Instead of nested closures we now have a simple chain of steps
   my $delay = Mojo::IOLoop->delay(
-    sub {
-      my $delay = shift;
-      Mojo::IOLoop->timer(3 => $delay->begin);
-    },
-    sub {
-      my $delay = shift;
+    sub ($delay) { Mojo::IOLoop->timer(3 => $delay->begin) },
+    sub ($delay) {
       say '3 seconds';
       Mojo::IOLoop->timer(3 => $delay->begin);
     },
-    sub {
-      my $delay = shift;
+    sub ($delay) {
       say '6 seconds';
       Mojo::IOLoop->timer(3 => $delay->begin);
     },
-    sub {
-      my $delay = shift;
-      say '9 seconds';
-    }
+    sub ($delay) { say '9 seconds' }
   );
   $delay->wait;
 
@@ -167,10 +153,7 @@ needs to be executed when the event has completed to decrement the event counter
 generated by this method have been executed and the event counter has reached zero, L</"steps"> will continue.
 
   # Capture all arguments except for the first one (invocant)
-  my $delay = Mojo::IOLoop->delay(sub {
-    my ($delay, $err, $stream) = @_;
-    ...
-  });
+  my $delay = Mojo::IOLoop->delay(sub ($delay, $err, $stream) { ... });
   Mojo::IOLoop->client({port => 3000} => $delay->begin);
   $delay->wait;
 
@@ -179,26 +162,17 @@ of C<1> with no default length. The arguments are then combined in the same orde
 together to the next step.
 
   # Capture all arguments
-  my $delay = Mojo::IOLoop->delay(sub {
-    my ($delay, $loop, $err, $stream) = @_;
-    ...
-  });
+  my $delay = Mojo::IOLoop->delay(sub ($delay, $loop, $err, $stream) { ... });
   Mojo::IOLoop->client({port => 3000} => $delay->begin(0));
   $delay->wait;
 
   # Capture only the second argument
-  my $delay = Mojo::IOLoop->delay(sub {
-    my ($delay, $err) = @_;
-    ...
-  });
+  my $delay = Mojo::IOLoop->delay(sub ($delay, $err) { ... });
   Mojo::IOLoop->client({port => 3000} => $delay->begin(1, 1));
   $delay->wait;
 
   # Capture and combine arguments
-  my $delay = Mojo::IOLoop->delay(sub {
-    my ($delay, $three_err, $three_stream, $four_err, $four_stream) = @_;
-    ...
-  });
+  my $delay = Mojo::IOLoop->delay(sub ($delay, $three_err, $three_stream, $four_err, $four_stream) { ... });
   Mojo::IOLoop->client({port => 3000} => $delay->begin);
   Mojo::IOLoop->client({port => 4000} => $delay->begin);
   $delay->wait;
